@@ -75,7 +75,26 @@ def manage_addGroupsFromLDAPMultiPlugin(self, id, title, server, port,
     # Instantiate the folderish adapter object
     plugin = GroupsFromLDAPMultiPlugin(id, title=title)
     self._setObject(id, plugin)
-    plugin.manage_changeConfiguration(REQUEST, fromadd=True)
+    
+    if REQUEST is None:
+        req = {
+            'form': {
+                'server': server,
+                'port': port,
+                'managerdn': managerdn,
+                'password': password,
+                'groupdn': groupdn,
+                'scope': scope,
+                'objectclasses': objectclasses,
+                'escapevalues': escapevalues,
+                'attributeid': attributeid,
+                'attributetitle': attributetitle,
+                'attributemembers': attributemembers,
+            },
+        }
+    else:
+        req = REQUEST
+    plugin.manage_changeConfiguration(req, fromadd=True)
     
     if REQUEST is not None:
         REQUEST.RESPONSE.redirect('%s/manage_main' % self.absolute_url())
@@ -558,9 +577,16 @@ class GroupsFromLDAPMultiPlugin(BasePlugin, Cacheable):
     security.declareProtected( ManageGroups, 'manage_changeConfiguration' )
     def manage_changeConfiguration(self, REQUEST=None, fromadd=False):
         """ manages submitted form """
-        for key in REQUEST.form.keys():
+        if not REQUEST:
+            return
+        if hasattr(REQUEST, 'form'):
+            form = REQUEST.form
+        else:
+            # case adding from setuphandler
+            form = REQUEST['form']
+        for key in form.keys():
             if key in self.config.keys():
-                self.config[key] = REQUEST.form.get(key)
+                self.config[key] = form.get(key)
                 # special list handling
                 if key == 'objectclasses':
                     self.config[key] = [c.strip() for c in self.config[key].split(',')]
